@@ -1,4 +1,5 @@
 import logging
+import numpy as np
 from sherlockpipe.star import starinfo
 from sherlockpipe.objectinfo.ObjectProcessingError import ObjectProcessingError
 from sherlockpipe.objectinfo.preparer.LightcurveBuilder import LightcurveBuilder
@@ -32,7 +33,14 @@ class MissionLightcurveBuilder(LightcurveBuilder):
             lcf = lk.search_lightcurvefile(str(mission_id), mission=mission, cadence="short").download_all()
         if lcf is None:
             raise ObjectProcessingError("Light curve not found for object id " + mission_id)
-        lc = lcf.PDCSAP_FLUX.stitch().remove_nans()
+        lc = None
+        for i in range(0, len(lcf.PDCSAP_FLUX)):
+            if lcf.PDCSAP_FLUX[i].label == mission_id:
+                if lc is None:
+                    lc = lcf.PDCSAP_FLUX[i]
+                else:
+                    lc.append(lcf.PDCSAP_FLUX[i])
+        lc = lc.remove_nans()
         transits_min_count = 1 if len(lcf) == 0 else 2
         if mission_prefix == self.MISSION_ID_KEPLER or mission_id == self.MISSION_ID_KEPLER_2:
             quarters = [lcfile.quarter for lcfile in lcf]
@@ -42,4 +50,4 @@ class MissionLightcurveBuilder(LightcurveBuilder):
             logging.info("Correcting K2 motion in light curve...")
             quarters = [lcfile.campaign for lcfile in lcf]
             lc = lc.to_corrector("sff").correct(windows=20)
-        return lc, star_info, transits_min_count, sectors, quarters
\ No newline at end of file
+        return lc, star_info, transits_min_count, np.unique(sectors), np.unique(quarters)
\ No newline at end of file
